AddressNode class

城市的数据模型

Constructors

AddressNode({String? name, String? code, String? letter})

Properties

code ↔ String?
代码
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
letter ↔ String?
首字母
getter/setter pair
name ↔ String?
名称
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited