ExpandableListController class

Controller for listen sticky header offset and current sticky header index.

Inheritance

Constructors

ExpandableListController()

Properties

containerOffsets ↔ List<double?>
store ExpandableSectionContainer information. SliverList index, layoutOffset. don't modify it.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
percent → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickySectionIndex ↔ int
get pinned header index
getter/setter pair
switchingSectionIndex → int
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
forceNotifyListeners() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
override
updatePercent(int sectionIndex, double percent) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited