ExpandableListSection<T> class abstract

Used to provide information for each section, each section model should implement ExpandableListSection<Item Model>.

Implementers

Constructors

ExpandableListSection()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getItems() → List<T>?
isSectionExpanded() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSectionExpanded(bool expanded) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited