ExpandableSectionContainerInfo class

Section widget information.

Constructors

ExpandableSectionContainerInfo({Widget? header, Widget? content, SliverChildBuilderDelegate? childDelegate, required int listIndex, required List<int> sectionRealIndexes, required bool separated, required ExpandableListController controller, required int sectionIndex, required bool sticky, required bool overlapsContent})

Properties

childDelegate → SliverChildBuilderDelegate?
final
content ↔ Widget?
getter/setter pair
controller → ExpandableListController
final
hashCode → int
The hash code for this object.
no setteroverride
getter/setter pair
listIndex → int
final
overlapsContent → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionIndex → int
final
sectionRealIndexes → List<int>
final
separated → bool
final
sticky → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override